@@ -1,6 +1,7 @@
 from firstimpression.constants import TEMP_FOLDER
 from firstimpression.constants import APIS
 from firstimpression.constants import LOCAL_INTEGRATED_FOLDER
+from firstimpression.constants import NAMELEVEL
 from firstimpression.file import download_install_media
 from firstimpression.file import update_directories_api
 from firstimpression.file import check_too_old
@@ -9,7 +10,6 @@ from firstimpression.file import xml_to_root
 from firstimpression.xml import get_xml
 from firstimpression.scala import log
 from firstimpression.scala import variables
-from logging import _nameToLevel
 import xml.etree.ElementTree as ET
 import os
 import glob
@@ -23,7 +23,10 @@ XML_FILENAME = 'amber_alert.xml'
 XML_FILENAME_CONTENT = 'amber_alert*.xml'
 URL = 'https://media.amberalert.nl/xml/combined/index.xml'
 XML_TEMP_PATH = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
-XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, XML_FILENAME_CONTENT)
+XML_LOCAL_PATH = os.path.join(LOCAL_INTEGRATED_FOLDER,
+                                NAME,
+                                XML_FILENAME_CONTENT
+                            )
 URL_LOGO = 'http://fimp.nl/narrowcasting/amberalert.png'
 
 MAX_FILE_AGE = 60 * 10
@@ -49,9 +52,10 @@ TAGS = {
 # MAIN FUNCTIONS API
 ##################################################################################################
 
+
 def run_api():
     update_directories_api(NAME)
-    
+
     if check_too_old(XML_TEMP_PATH, MAX_FILE_AGE):
         root = get_xml(URL)
         new_root = ET.Element("root")
@@ -62,13 +66,14 @@ def run_api():
         for alert in get_alerts(root):
             counter += 1
             new_root.append(parse_alert(alert))
-        
+
         ET.SubElement(new_root, "alerts").text = str(counter)
 
         write_root_to_xml_files(new_root, XML_TEMP_PATH, NAME)
-        
+
     else:
-        log(_nameToLevel['INFO'],'File not old enough to update')
+        log(NAMELEVEL['INFO'], 'File not old enough to update')
+
 
 def check_api():
     svars = variables()
@@ -81,9 +86,9 @@ def check_api():
         svars['skipscript'] = False
 
         amount_items = int(xml_to_root(file_path).get('alerts', '0'))
-        
+
         svars['total_items'] = amount_items
-        
+
         if amount_items == 0:
             svars['skipscript'] = True
 
@@ -91,9 +96,11 @@ def check_api():
 # MEDIA FUNCTIONS
 ##################################################################################################
 
+
 def download_install_logo():
     download_install_media(URL_LOGO, TEMP_FOLDER, NAME)
 
+
 def download_photo_child(url):
     return download_install_media(url, TEMP_FOLDER, NAME)
 
@@ -101,36 +108,46 @@ def download_photo_child(url):
 # GET FUNCTIONS
 ##################################################################################################
 
+
 def get_alerts(root):
     return root.findall(TAGS['alert'], NAMESPACE_XML)
 
+
 def get_alert_soort(alert):
     if alert.findtext(TAGS['soort'], '0', NAMESPACE_XML) == '10':
         return 'Amber Alert'
     else:
         return 'Vermist kind'
 
+
 def get_alert_status(alert):
     return alert.findtext(TAGS['status'], 'Onbekend', NAMESPACE_XML)
 
+
 def get_alert_type(alert):
     return alert.findtext(TAGS['type'], 'Onbekend', NAMESPACE_XML)
 
+
 def get_alert_message(alert):
     return alert.find(TAGS['message'], NAMESPACE_XML)
 
+
 def get_name_child(message):
     return message.findtext(TAGS['name'], 'Onbekend', NAMESPACE_XML)
 
+
 def get_message_description(message):
     return message.findtext(TAGS['description'], '', NAMESPACE_XML)
 
+
 def get_more_info_url(message):
     return message.findtext(TAGS['readmore'], '', NAMESPACE_XML)
 
+
 def get_amber_url(message):
     return message.findtext(TAGS['amberlink'], '', NAMESPACE_XML)
 
+
 def get_photo_child(message):
     media_url = message.findtext(TAGS['image'], None, NAMESPACE_XML)
 
@@ -143,6 +160,7 @@ def get_photo_child(message):
 # PARSE FUNCTIONS
 ##################################################################################################
 
+
 def parse_alert(alert):
     item = ET.Element("item")
     ET.SubElement(item, "soort").text = get_alert_soort(alert)
