@@ -104,19 +104,17 @@ TAGS = {
 # MAIN FUNCTIONS API
 ##################################################################################################
 
-def run_api(api_key, icon_set, use_video, location, units):
+def run_api(api_key, icon_set, location, units, lang='nl'):
     params = {
         'q': location,
         'appid': api_key, 
-        'units': units
+        'units': units,
+        'lang': lang
     }
 
     url_icons = 'http://37.97.211.104/narrowcasting/weather/weather_{}'.format(icon_set)
 
-    if use_video:
-        extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
-    else:
-        extensions = IMG_EXTENSIONS
+    extensions = IMG_EXTENSIONS + VIDEO_EXTENSIONS
     
     temp_folder_icons = os.path.join(TEMP_FOLDER, NAME, 'icons', icon_set)
     local_folder_icons = os.path.join(LOCAL_INTEGRATED_FOLDER, NAME, 'icons', icon_set)
@@ -251,11 +249,6 @@ def get_pressure(current_weather):
 def get_temperature(day):
     return day.get(TAGS['temp'], {})
 
-def round_temperature(temp):
-    if isinstance(temp, str):
-        return temp
-    else:
-        return round(temp, TEMPERATURE_DECIMALS)
 
 def get_max_temperature(weather):
     info = get_weather_info(weather)
@@ -355,3 +348,9 @@ def get_weekday(day):
 ##################################################################################################
 # PARSE FUNCTIONS
 ##################################################################################################
+
+def round_temperature(temp):
+    if isinstance(temp, str):
+        return temp
+    else:
+        return round(temp, TEMPERATURE_DECIMALS)
